<?PHP
/**
 * Constains lists for categorizing links between objects and tags.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Constains lists for categorizing links between objects and tags.
 */
final class MDConcObjectTagRelTypes implements MDImporterConcordanceListInterface {

    private const RELATION_TYPE_NAMES = [

        '' => 'tag',
        'tag' => 'tag',
        'schlagwort' => 'tag',
        'Motivgattung' => 'tag',
        'motivgattung' => 'tag',
        'Assoziation' => 'tag',
        'assoziation' => 'tag',
        'description' => 'tag',
        'emotion' => 'tag',
        'atmosphäre' => 'tag',

        "motive" => "display_subject",
        "motiv" => "display_subject",
        "display" => "display_subject",
        "Bildelement" => "display_subject",

        "material" => "material",

        "technique" => "technique",
        "technik" => "technique",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (isset(self::RELATION_TYPE_NAMES[$input])) {
            return self::RELATION_TYPE_NAMES[$input];
        }
        if (isset(self::RELATION_TYPE_NAMES[strtolower($input)])) {
            return self::RELATION_TYPE_NAMES[strtolower($input)];
        }

        throw new MDImporterMissingConcordance("Unknown object-tag relationship type: " . $input);

    }
}
