<?PHP
/**
 * Constains lists for resolving literal ownership status to the expected names.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out ownership status types.
 */
final class MDConcOwnershipStatus implements MDImporterConcordanceListInterface {

    private const OWNERSHIP_TYPES_VERBOSE = [

        // 0: No known entry type
        "Eigentum" => "owned",
        "Geschenk" => "owned",
        "Besitz" => "owned",
        "Kauf" => "owned",
        "Fund" => "owned",
        "Eigenleistung" => "owned",
        "Eigentum des Museums" => "owned",
        "j" => "owned",
        "+" => "owned",
        "Eigentum Land Berlin" => "owned",

        // Permanent loans
        "Dauerleihe" => "permanent_loan",
        "Dauerleihgabe" => "permanent_loan",

        // Loans
        "Leihe" => "borrowed",
        "Leihgabe" => "borrowed",
        "Ensemble soll bei Umzug des Möbeldepots an Senat zurückgegeben werden (Jan. 2009)" => "borrowed",
        "Leihgabe 13.8.96" => "borrowed",

        // Owned by others => third_party_property
        'Third party property' => 'third_party_property',
        'Fremdeigentum' => 'third_party_property',

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::OWNERSHIP_TYPES_VERBOSE[$input])) {
            if (isset(self::OWNERSHIP_TYPES_VERBOSE[trim($input)])) {
                return self::OWNERSHIP_TYPES_VERBOSE[trim($input)];
            }
            throw new MDImporterMissingConcordance("Unknown ownership type: " . $input);
        }

        return self::OWNERSHIP_TYPES_VERBOSE[$input];

    }
}
